diff --git a/version.sh b/version.sh
index a91c48b..49f2b7f 100755
--- a/version.sh
+++ b/version.sh
@@ -1,12 +1,21 @@
 #!/bin/sh
-VER=`svnversion .`
-if [ "x$VER" != x -a "$VER" != exported ]
-then
-  echo "#define X264_VERSION \" svn-$VER\"" >> config.h
-  VER=`echo $VER | sed -e 's/[^0-9].*//'`
+
+HEAD_HASH=`git-show-ref HEAD | cut -c 1-6`
+HEAD_VER=`git-rev-list refs/remotes/origin/HEAD | wc | awk '{print $1}'`
+MASTER_VER=`git-rev-list refs/remotes/origin/master | wc | awk '{print $1}'`
+LOCAL_VER=`git-rev-list refs/heads/master | wc | awk '{print $1}'`
+MODIFIED=`git diff | grep "diff --git" | wc -l`
+
+if [ "$MODIFIED" -gt 0 ]  && [ $HEAD_VER != $LOCAL_VER ]; then
+  echo "#define X264_VERSION \"git-${LOCAL_VER}M:$HEAD_VER\"" >> config.h
+elif [ "$MODIFIED" -gt 0 ] && [ $HEAD_VER == $MASTER_VER ]; then
+  echo "#define X264_VERSION \"git-${HEAD_VER}M\"" >> config.h
+elif [ $MODIFIED == 0 ] && [ $HEAD_VER != $LOCAL_VER ]; then
+  echo "#define X264_VERSION \"git-${LOCAL_VER}:${HEAD_VER}\"" >> config.h
 else
-  echo "#define X264_VERSION \"\"" >> config.h
-  VER="x"
+  echo "#define X264_VERSION \"git-${HEAD_VER} ($HEAD_HASH)\"" >> config.h
 fi
+
+VER=`grep '#define X264_VERSION' < config.h | awk -F\git- '{print $2}' | sed s/\"//g`
 API=`grep '#define X264_BUILD' < x264.h | sed -e 's/.* \([1-9][0-9]*\).*/\1/'`
 echo "#define X264_POINTVER \"0.$API.$VER\"" >> config.h
